==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/AST/ASTWalker.h <==
// public class soot.dava.toolkits.base.AST.ASTWalker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2233dc8ea4202841 soot_dava_toolkits_base_AST_ASTWalker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_AST_ASTWalker_H_
#define _JC_soot_dava_toolkits_base_AST_ASTWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Value$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs	_jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs	_jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$refs	_jc_soot_dava_toolkits_base_AST_ASTWalker$refs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs	_jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object	_jc_soot_dava_toolkits_base_AST_ASTWalker$object;

typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods	_jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtable	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtable;
typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$walk__5fstmt$f5c8abd9db4c21c8(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *);
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$walk__5fvalue$b3bccf2df083425c(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_AST_ASTWalker$method_info$walk__5fstmt$f5c8abd9db4c21c8;
extern _jc_method _jc_soot_dava_toolkits_base_AST_ASTWalker$method_info$walk__5fvalue$b3bccf2df083425c;

// Static methods
extern struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *_jc_soot_dava_toolkits_base_AST_ASTWalker$method$v$498c6f819a58a182(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods {
	void	(*walk__5fstmt$f5c8abd9db4c21c8)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *);
	void	(*walk__5fvalue$b3bccf2df083425c)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods	soot_dava_toolkits_base_AST_ASTWalker;
};

// Vtype
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$refs {
    _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs	soot_dava_toolkits_base_AST_ASTWalker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs	soot_dava_toolkits_base_AST_ASTWalker;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object {
	_jc_soot_dava_toolkits_base_AST_ASTWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtype	*vtype;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype _jc_soot_dava_toolkits_base_AST_ASTWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_AST_ASTWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_AST_ASTWalker$class_object;

#endif	/* _JC_soot_dava_toolkits_base_AST_ASTWalker_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/AST/ASTWalker.h <==
// public class soot.dava.toolkits.base.AST.ASTWalker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2233dc8ea4202841 soot_dava_toolkits_base_AST_ASTWalker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_AST_ASTWalker_H_
#define _JC_soot_dava_toolkits_base_AST_ASTWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Value$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs	_jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs	_jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$refs	_jc_soot_dava_toolkits_base_AST_ASTWalker$refs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs	_jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object	_jc_soot_dava_toolkits_base_AST_ASTWalker$object;

typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods	_jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtable	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtable;
typedef const struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$walk__5fstmt$f5c8abd9db4c21c8(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_AST_ASTWalker$method$walk__5fvalue$b3bccf2df083425c(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_AST_ASTWalker$method_info$walk__5fstmt$f5c8abd9db4c21c8;
extern _jc_method _jc_soot_dava_toolkits_base_AST_ASTWalker$method_info$walk__5fvalue$b3bccf2df083425c;

// Static methods
extern struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *_jc_soot_dava_toolkits_base_AST_ASTWalker$method$v$498c6f819a58a182(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods {
	void	(*walk__5fstmt$f5c8abd9db4c21c8)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*walk__5fvalue$b3bccf2df083425c)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vmethods	soot_dava_toolkits_base_AST_ASTWalker;
};

// Vtype
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$refs {
    _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_refs	soot_dava_toolkits_base_AST_ASTWalker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_AST_ASTWalker$sub_nonrefs	soot_dava_toolkits_base_AST_ASTWalker;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_AST_ASTWalker$object {
	_jc_soot_dava_toolkits_base_AST_ASTWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$vtype	*vtype;
	_jc_soot_dava_toolkits_base_AST_ASTWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_AST_ASTWalker$vtype _jc_soot_dava_toolkits_base_AST_ASTWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_AST_ASTWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_AST_ASTWalker$class_object;

#endif	/* _JC_soot_dava_toolkits_base_AST_ASTWalker_H_ */
